==> workbench_approver-1.0.0.tar.gz: workbench_approver/modules/workbench_approver_access/tests/src/Functional/ApproverAccessTestBase.php <==
<?php

namespace Drupal\Tests\workbench_approver_access\Functional;

use Drupal\node\Entity\NodeType;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\workbench_access\Traits\WorkbenchAccessTestTrait;
use Drupal\Tests\workbench_approver\Functional\WorkbenchApproverTestBase;

/**
 * Base class for Workbench access integration tests.
 *
 * @group workbench_approver
 */
abstract class ApproverAccessTestBase extends WorkbenchApproverTestBase {

  use WorkbenchAccessTestTrait;

  /**
   * The access scheme.
   *
   * @var \Drupal\workbench_access\Entity\AccessSchemeInterface
   */
  public $scheme;

  /**
   * The vocabulary for the access scheme.
   *
   * @var \Drupal\taxonomy\Entity\Vocabulary
   */
  public $vocabulary;

  /**
   * The root term of the vocabulary.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $baseTerm;

  /**
   * A term with $baseTerm as its parent.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $subTerm;

  /**
   * A term that has no parent.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $unrelatedTerm;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'workbench_access',
    'workbench_approver',
    'workbench_approver_access',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // The page content type from Workbench access tests.
    $this->setUpContentType();

    // Account for new permissions.
    $role_storage = $this->container->get('entity_type.manager')->getStorage('user_role');
    $rids = ['admin', 'editor'];
    $permissions = [
      'access administration pages',
      'create page content',
      'edit any page content',
      'administer menu',
      'delete any page content',
      'use workbench access',
    ];
    foreach ($rids as $rid) {
      $role = $role_storage->load($rid);
      foreach ($permissions as $permission) {
        $role->grantPermission($permission)->save();
      }
    }

    $this->addEntityTypeAndBundleToWorkflow($this->workflow, 'node', 'page');

    // Set up a content type, taxonomy field, and taxonomy scheme.
    $this->vocabulary = $this->setUpVocabulary();
    $node_type = NodeType::load('page');
    $field = $this->setUpTaxonomyFieldForEntityType('node', 'page', $this->vocabulary->id());
    $this->assertEquals($field->getDefaultValueLiteral(), []);
    $this->scheme = $this->setUpTaxonomyScheme($node_type, $this->vocabulary);

    // Setup terms for the test.
    $this->baseTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Editor',
    ]);
    $this->baseTerm->save();
    $this->subTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Sub-editor',
      'parent' => $this->baseTerm->id(),
    ]);
    $this->subTerm->save();
    $this->unrelatedTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Unrelated',
    ]);
    $this->unrelatedTerm->save();
  }

  /**
   * Setup conditions for the "deny on empty" setting.
   *
   * @return void
   *   No return value.
   */
  public function assertDenyOnEmpty(): void {
    $config = $this->container->get('config.factory')->getEditable('workbench_access.settings');
    $this->assertTrue($config->get('deny_on_empty') === FALSE);
    $config->set('deny_on_empty', TRUE)->save();
    $this->assertTrue($config->get('deny_on_empty') === TRUE);
  }

  /**
   * Setup conditions for user access assignment.
   *
   * The editorUser is assigned to the baseTerm section.
   *
   * @return void
   *   No return value.
   */
  public function assertSectionAssigned(): void {
    $user_storage = $this->container->get('workbench_access.user_section_storage');
    $user_storage->addUser($this->scheme, $this->editorUser, [$this->baseTerm->id()]);
    $expected = [$this->editorUser->id()];
    $existing_users = $user_storage->getEditors($this->scheme, $this->baseTerm->id());
    $this->assertEquals($expected, array_keys($existing_users));
  }

  /**
   * Setup conditions for role access assignment.
   *
   * The editor role is assigned to the baseTerm section.
   *
   * @return void
   *   No return value.
   */
  public function assertAddSectionToEditorRole(): void {
    $role_storage = $this->container->get('workbench_access.role_section_storage');
    $role_storage->addRole($this->scheme, 'editor', [$this->baseTerm->id()]);
    $this->assertEquals(['editor'], $role_storage->getRoles($this->scheme, $this->baseTerm->id()));
  }

}

==> workbench_approver-1.0.1.tar.gz: workbench_approver/modules/workbench_approver_access/tests/src/Functional/ApproverAccessTestBase.php <==
<?php

namespace Drupal\Tests\workbench_approver_access\Functional;

use Drupal\node\Entity\NodeType;
use Drupal\taxonomy\Entity\Term;
use Drupal\Tests\workbench_access\Traits\WorkbenchAccessTestTrait;
use Drupal\Tests\workbench_approver\Functional\WorkbenchApproverTestBase;

/**
 * Base class for Workbench Access integration tests.
 *
 * @group workbench_approver
 */
abstract class ApproverAccessTestBase extends WorkbenchApproverTestBase {

  use WorkbenchAccessTestTrait;

  /**
   * The access scheme.
   *
   * @var \Drupal\workbench_access\Entity\AccessSchemeInterface
   */
  public $scheme;

  /**
   * The vocabulary for the access scheme.
   *
   * @var \Drupal\taxonomy\Entity\Vocabulary
   */
  public $vocabulary;

  /**
   * The root term of the vocabulary.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $baseTerm;

  /**
   * A term with $baseTerm as its parent.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $subTerm;

  /**
   * A term that has no parent.
   *
   * @var \Drupal\taxonomy\TermInterface
   */
  public $unrelatedTerm;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'workbench_access',
    'workbench_approver',
    'workbench_approver_access',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // The page content type from Workbench Access tests.
    $this->setUpContentType();

    // Account for new permissions.
    $role_storage = $this->container->get('entity_type.manager')->getStorage('user_role');
    $rids = ['admin', 'editor'];
    $permissions = [
      'access administration pages',
      'create page content',
      'edit any page content',
      'administer menu',
      'delete any page content',
      'use workbench access',
    ];
    foreach ($rids as $rid) {
      $role = $role_storage->load($rid);
      foreach ($permissions as $permission) {
        $role->grantPermission($permission)->save();
      }
    }

    $this->addEntityTypeAndBundleToWorkflow($this->workflow, 'node', 'page');

    // Set up a content type, taxonomy field, and taxonomy scheme.
    $this->vocabulary = $this->setUpVocabulary();
    $node_type = NodeType::load('page');
    $field = $this->setUpTaxonomyFieldForEntityType('node', 'page', $this->vocabulary->id());
    $this->assertEquals($field->getDefaultValueLiteral(), []);
    $this->scheme = $this->setUpTaxonomyScheme($node_type, $this->vocabulary);

    // Setup terms for the test.
    $this->baseTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Editor',
    ]);
    $this->baseTerm->save();
    $this->subTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Sub-editor',
      'parent' => $this->baseTerm->id(),
    ]);
    $this->subTerm->save();
    $this->unrelatedTerm = Term::create([
      'vid' => $this->vocabulary->id(),
      'name' => 'Unrelated',
    ]);
    $this->unrelatedTerm->save();
  }

  /**
   * Setup conditions for the "deny on empty" setting.
   *
   * @return void
   *   No return value.
   */
  public function assertDenyOnEmpty(): void {
    $config = $this->container->get('config.factory')->getEditable('workbench_access.settings');
    $this->assertTrue($config->get('deny_on_empty') === FALSE);
    $config->set('deny_on_empty', TRUE)->save();
    $this->assertTrue($config->get('deny_on_empty') === TRUE);
  }

  /**
   * Setup conditions for user access assignment.
   *
   * The editorUser is assigned to the baseTerm section.
   *
   * @return void
   *   No return value.
   */
  public function assertSectionAssigned(): void {
    $user_storage = $this->container->get('workbench_access.user_section_storage');
    $user_storage->addUser($this->scheme, $this->editorUser, [$this->baseTerm->id()]);
    $expected = [$this->editorUser->id()];
    $existing_users = $user_storage->getEditors($this->scheme, $this->baseTerm->id());
    $this->assertEquals($expected, array_keys($existing_users));
  }

  /**
   * Setup conditions for role access assignment.
   *
   * The editor role is assigned to the baseTerm section.
   *
   * @return void
   *   No return value.
   */
  public function assertAddSectionToEditorRole(): void {
    $role_storage = $this->container->get('workbench_access.role_section_storage');
    $role_storage->addRole($this->scheme, 'editor', [$this->baseTerm->id()]);
    $this->assertEquals(['editor'], $role_storage->getRoles($this->scheme, $this->baseTerm->id()));
  }

}
